==> haskell-pem-0.2.4-25-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pem.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pem
version: 0.2.4
id: pem-0.2.4-AIUScaLhdy15tYKE52RILJ
key: pem-0.2.4-AIUScaLhdy15tYKE52RILJ
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-pem
synopsis: Privacy Enhanced Mail (PEM) format reader and writer.
description:
    Privacy Enhanced Mail (PEM) format reader and writer. long description
category: Data
abi: e568ff920ae0205f199ee05023ca724b
exposed: True
exposed-modules:
    Data.PEM
hidden-modules: Data.PEM.Parser Data.PEM.Writer Data.PEM.Types
import-dirs: /usr/lib/ghc-8.4.3/site-local/pem-0.2.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/pem-0.2.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-pem
hs-libraries: HSpem-0.2.4-AIUScaLhdy15tYKE52RILJ
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    basement-0.0.8-8QjArDsw3GWCcbHE5iqtz3
    memory-0.14.16-FrHKJ6EcQ5I95PPEhrgDqk
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             basement-0.0.8-8QjArDsw3GWCcbHE5iqtz3=ca5c41f50e204df2ae81595eb33f7115
             memory-0.14.16-FrHKJ6EcQ5I95PPEhrgDqk=23a2e2ee61129c4073d4aeb70df9c169
haddock-interfaces: /usr/share/doc/haskell-pem/html/pem.haddock
haddock-html: /usr/share/doc/haskell-pem/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pem-0.2.4-28-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pem.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pem
version: 0.2.4
id: pem-0.2.4-1iHlIuqHoDl6HhAIWSlwjG
key: pem-0.2.4-1iHlIuqHoDl6HhAIWSlwjG
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-pem
synopsis: Privacy Enhanced Mail (PEM) format reader and writer.
description:
    Privacy Enhanced Mail (PEM) format reader and writer. long description
category: Data
abi: 86cf480afd5c42476065f57ea79fa6f6
exposed: True
exposed-modules:
    Data.PEM
hidden-modules: Data.PEM.Parser Data.PEM.Writer Data.PEM.Types
import-dirs: /usr/lib/ghc-8.4.3/site-local/pem-0.2.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/pem-0.2.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-pem
hs-libraries: HSpem-0.2.4-1iHlIuqHoDl6HhAIWSlwjG
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    basement-0.0.8-8QjArDsw3GWCcbHE5iqtz3
    memory-0.14.18-9akydHRk1ZP1zabNg9e0SJ
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             basement-0.0.8-8QjArDsw3GWCcbHE5iqtz3=ca5c41f50e204df2ae81595eb33f7115
             memory-0.14.18-9akydHRk1ZP1zabNg9e0SJ=a6560a06cd4458200b1075ace7506fc2
haddock-interfaces: /usr/share/doc/haskell-pem/html/pem.haddock
haddock-html: /usr/share/doc/haskell-pem/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
